# Section81Response

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**section_81_reference_number** | **str** |  | 
**date_created** | **datetime** |  | 
**location_description** | **str** |  | 
**section_81_severity** | [**Section81SeverityResponse**](Section81SeverityResponse.md) |  | [optional] 
**section_81_severity_string** | **str** |  | [optional] 
**section_81_status** | [**Section81StatusResponse**](Section81StatusResponse.md) |  | 
**section_81_status_string** | **str** |  | 
**section_81_type** | [**Section81TypeResponse**](Section81TypeResponse.md) |  | 
**section_81_type_string** | **str** |  | 
**work_reference_number** | **str** |  | 
**usrn** | **float** |  | 
**street_name** | **str** |  | 
**town** | **str** |  | [optional] 
**area** | **str** |  | [optional] 
**road_category** | **float** |  | 
**works_coordinates** | **object** |  | 
**highway_authority** | **str** |  | 
**highway_authority_swa_code** | **str** |  | 
**promoter_organisation** | **str** |  | 
**promoter_swa_code** | **str** |  | 
**workstream_prefix** | **str** |  | 
**location_types** | [**list[LocationTypeResponse]**](LocationTypeResponse.md) |  | 
**location_types_string** | **list[str]** |  | 
**inspection_date** | **datetime** |  | 
**other_type_details** | **str** |  | [optional] 
**made_safe_by_ha** | **bool** |  | [optional] 
**inspector_name** | **str** |  | [optional] 
**inspector_contact_number** | **str** |  | [optional] 
**additional_details** | **str** |  | 
**status_changed_date** | **datetime** |  | 
**promoter_response** | **str** |  | [optional] 
**section_81_work_type** | **AllOfSection81ResponseSection81WorkType** |  | [optional] 
**section_81_work_type_string** | **str** |  | [optional] 
**promoter_status** | **AllOfSection81ResponsePromoterStatus** |  | [optional] 
**promoter_status_string** | **str** |  | [optional] 
**promoter_status_changed_date** | **datetime** |  | [optional] 
**linked_permit** | **AllOfSection81ResponseLinkedPermit** |  | [optional] 
**files** | [**list[FileSummaryResponse]**](FileSummaryResponse.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

